@@ -13,6 +13,7 @@
 #include <sys/socket.h>
 #include <netinet/in.h> /* for htonl and ntohl */
 #include <linux/atm.h>
+#include <atm.h>
 
 
 static const char *pti[] = { "Data SDU 0","Data SDU 1","Data SDU 0, CE",
@@ -42,7 +43,7 @@ static void usage(const char *name)
 {
     int i;
 
-    fprintf(stderr,"usage: %s [ -t type [ -g gfc ] [ -c ] ] itf vpi vci\n",
+    fprintf(stderr,"usage: %s [ -t type [ -g gfc ] [ -c ] ] [itf.]vpi.vci\n",
       name);
     for (i = 0; i < 8; i++)
 	fprintf(stderr,"  %-6s %d %s\n",i ? "" : "type",i,pti[i]);
@@ -78,18 +79,22 @@ int main(int argc,char **argv)
 	    default:
 		usage(name);
 	}
-    if (argc != optind+3) usage(name);
+    if (argc != optind+1) usage(name);
     if ((s = socket(PF_ATMPVC,SOCK_DGRAM,ATM_AAL0)) < 0) {
 	perror("socket");
 	return 1;
     }
     memset(&addr,0,sizeof(addr));
-    addr.sap_family = AF_ATMPVC;
-    addr.sap_addr.itf = atoi(argv[optind]);
-    addr.sap_addr.vpi = atoi(argv[optind+1]);
-    addr.sap_addr.vci = atoi(argv[optind+2]);
-    if (type == -1) addr.sap_rxtp.class = ATM_UBR;
-    else addr.sap_txtp.class = ATM_UBR;
+    if (text2atm(argv[optind],(struct sockaddr *) &addr,sizeof(addr),T2A_PVC)
+      < 0) usage(name);
+    if (type == -1) {
+	addr.sap_rxtp.class = ATM_UBR;
+	addr.sap_rxtp.max_sdu = 52;
+    }
+    else {
+	addr.sap_txtp.class = ATM_UBR;
+	addr.sap_txtp.max_sdu = 52;
+    }
     if (bind(s,(struct sockaddr *) &addr,sizeof(addr)) < 0) {
 	perror("bind");
 	return 1;
