@@ -55,7 +55,7 @@ int main(int argc,char **argv)
 	pool = strtol(argv[optind+1],&end,0);
 	if (*end || pool < 0 || pool > 31) usage(name);
     }
-    s = socket(AF_ATMPVC,SOCK_DGRAM,0);
+    s = socket(PF_ATMPVC,SOCK_DGRAM,0);
     if (s < 0) {
 	perror("socket");
 	return 1;
