@@ -1,6 +1,6 @@
 /* qlib.h - run-time library */
  
-/* Written 1995 by Werner Almesberger, EPFL-LRC */
+/* Written 1995,1996 by Werner Almesberger, EPFL-LRC */
  
  
 #ifndef QLIB_H
@@ -42,11 +42,11 @@ int q_create(Q_DSC *dsc,void *buf,int size);
 int q_close(Q_DSC *dsc);
 
 void q_assign(Q_DSC *dsc,int field,unsigned long value);
-void q_write(Q_DSC *dsc,int field,void *buf,int size);
+void q_write(Q_DSC *dsc,int field,const void *buf,int size);
 
-int q_present(Q_DSC *dsc,int field);
-unsigned long q_fetch(Q_DSC *dsc,int field);
+int q_present(const Q_DSC *dsc,int field);
+unsigned long q_fetch(const Q_DSC *dsc,int field);
 int q_read(Q_DSC *dsc,int field,void *buf,int size);
-int q_length(Q_DSC *dsc,int field);
+int q_length(const Q_DSC *dsc,int field);
 
 #endif
