@@ -12,6 +12,7 @@
 #include <sys/types.h>
 #include <linux/atm.h>
 
+#include "atm.h"
 #include "atmd.h"
 #include "qlib.h"
 
@@ -29,15 +30,15 @@ extern FILE *yyin;
 
 int net = 0;
 int debug = 0;
-short sig_itf = 0;
-
+int pretty = A2T_PRETTY | A2T_NAME;
 
 static SAAL_DSC saal;
 
 
 static void usage(const char *name)
 {
-    fprintf(stderr,"usage: %s [ -b ] [ -d ] [ -n ] [ interface ]\n",name);
+    fprintf(stderr,"usage: %s [ -b ] [ -d ] [ -n ] [ -N ]\n",
+      name);
     exit(1);
 }
 
@@ -215,7 +216,9 @@ int main(int argc,char **argv)
 
     set_application("atmsigd");
     background = 0;
-    while ((c = getopt(argc,argv,"bdn")) != EOF)
+    memset(&signaling_pvc,0,sizeof(signaling_pvc));
+    signaling_pvc.sap_addr.vci = 5;
+    while ((c = getopt(argc,argv,"bdnN")) != EOF)
 	switch (c) {
 	    case 'b':
 		background = 1;
@@ -226,12 +229,14 @@ int main(int argc,char **argv)
 		q_dump = 1;
 		break;
 	    case 'n':
+		pretty = A2T_PRETTY;
+		break;
+	    case 'N':
 		net = 1;
 		break;
 	    default:
 		usage(argv[0]);
 	}
-    if (optind == argc-1) sig_itf = atoi(argv[optind++]);
     if (optind != argc) usage(argv[0]);
     diag(COMPONENT,DIAG_INFO,"Linux ATM signaling UNI 3.x(red)/AAL5, version "
       VERSION);
@@ -242,7 +247,8 @@ int main(int argc,char **argv)
 	    return 1;
 	}
     diag(COMPONENT,DIAG_INFO,"Acting as %s side",net ? "NETWORK" : "USER");
-    if (open_all(sig_itf)) return 1;
+    if (open_all()) return 1;
+    init_addr();
     q_start();
     start_saal(&saal,&ops,NULL);
     saal_estab_req(&saal,NULL,0);
