@@ -15,6 +15,7 @@
 #include <linux/atmdev.h>
 #include <linux/atmsvc.h>
 
+#include "atm.h"
 #include "atmd.h"
 #include "q2931.h"
 
@@ -26,8 +27,7 @@
 
 
 struct timeval now;
-int signaling_vpi = 0;
-int signaling_vci = 5;
+struct sockaddr_atmpvc signaling_pvc;
 
 
 static int kernel,signaling;
@@ -94,7 +94,7 @@ void to_kernel(struct atmsvc_msg *msg)
     int size,wrote;
 
     size = bllis2msg(0);
-    for (walk = msg->remote.sas_addr.blli; walk; walk = walk->next)
+    for (walk = msg->svc.sas_addr.blli; walk; walk = walk->next)
 	size += sizeof(struct atm_blli);
     diag("KERNEL",DIAG_DEBUG,"TO KERNEL: %s (%d) for 0x%lx/0x%lx <%d>",
       as_name[msg->type],msg->reply,msg->vcc,msg->listen_vcc,size);
@@ -119,23 +119,18 @@ static void close_kernel(void)
 /* ----- signaling interface ----------------------------------------------- */
 
 
-static int open_signaling(int interface)
+static int open_signaling(void)
 {
-    struct sockaddr_atmpvc addr;
     int s;
 
     if ((s = socket(PF_ATMPVC,SOCK_DGRAM,ATM_AAL5)) < 0) {
 	perror("socket");
 	return -1;
     }
-    memset(&addr,0,sizeof(addr));
-    addr.sap_family = AF_ATMPVC;
-    addr.sap_addr.itf = interface;
-    addr.sap_addr.vpi = signaling_vpi;
-    addr.sap_addr.vci = signaling_vci;
-    addr.sap_rxtp.class = addr.sap_txtp.class = ATM_UBR;
-    addr.sap_rxtp.max_sdu = addr.sap_txtp.max_sdu = MAX_Q_MSG;
-    if (bind(s,(struct sockaddr *) &addr,sizeof(addr)) < 0) {
+    signaling_pvc.sap_family = AF_ATMPVC;
+    signaling_pvc.sap_rxtp.class = signaling_pvc.sap_txtp.class = ATM_UBR;
+    signaling_pvc.sap_rxtp.max_sdu = signaling_pvc.sap_txtp.max_sdu = MAX_Q_MSG;
+    if (bind(s,(struct sockaddr *) &signaling_pvc,sizeof(signaling_pvc)) < 0) {
 	perror("bind");
 	return -1;
     }
@@ -198,37 +193,59 @@ static void close_signaling(void)
 /* ----- addresses --------------------------------------------------------- */
 
 
-#define MAX_ADDRS 1024
+LOCAL_ADDR local_addr[MAX_ADDRS+1];
 
 
-int get_addr(int itf,struct sockaddr_atmsvc *addr)
+int get_addr(int itf)
 {
     struct atmif_sioc req;
     struct sockaddr_atmsvc buffer[MAX_ADDRS];
+    LOCAL_ADDR *from,*to;
+    int addrs,i;
 
+    for (from = to = local_addr; from->state != ls_unused; from++)
+	if (from->state != ls_removed) {
+	    from->state = itf == from->itf ? ls_removed : ls_same;
+	    *to++ = *from;
+	}
     req.number = itf;
     req.arg = buffer;
     req.length = sizeof(buffer);
     if (ioctl(kernel,ATM_GETADDR,&req) < 0)
 	diag(COMPONENT,DIAG_FATAL,"ioctl ATM_GETADDR yields \"%s\"",
 	  strerror(errno));
-    if (req.length) *addr = *buffer;
-    return req.length/sizeof(*addr);
+    addrs = req.length/sizeof(struct sockaddr_atmsvc);
+    for (i = 0; i < addrs; i++) {
+	for (from = local_addr; from->state != ls_unused; from++)
+	    if (from->itf == itf && atm_equal(buffer+i,&from->addr,0,0)) break;
+	if (from->state != ls_unused) from->state = ls_same;
+	else if (to == local_addr+MAX_ADDRS-1)
+		diag(COMPONENT,DIAG_WARN,"local address table overflow");
+	    else {
+		to->state = ls_added;
+		to->itf = itf;
+		to->addr = buffer[i];
+		to++;
+	    }
+    }
+    to->state = ls_unused;
+    return addrs;
 }
 
 
 /* ----- common part ------------------------------------------------------- */
 
 
-int open_all(int interface)
+int open_all(void)
 {
     kernel = open_kernel();
     if (kernel < 0) return -1;
-    signaling = open_signaling(interface);
+    signaling = open_signaling();
     if (signaling < 0) {
 	close_kernel();
 	return -1;
     }
+    local_addr[0].state = ls_unused;
     return 0;
 }
 
