@@ -1,6 +1,6 @@
 /* bw.c - block write */
 
-/* Written 1995 by Werner Almesberger, EPFL-LRC */
+/* Written 1995,1996 by Werner Almesberger, EPFL-LRC */
 
 
 #include <stdlib.h>
@@ -19,7 +19,7 @@
 
 static void usage(const char *name)
 {
-    fprintf(stderr,"usage: %s itf vpi vci [ blocks ]\n",name);
+    fprintf(stderr,"usage: %s [itf.]vpi.vci [ blocks ]\n",name);
     exit(1);
 }
 
