@@ -75,7 +75,7 @@ struct rusage {
 struct sockaddr_in sinme;
 struct sockaddr_in sinhim;
 struct sockaddr_in frominet;
-struct sockaddr_atmpvc satm;
+struct sockaddr_atmsvc satm;
 
 int domain, fromlen;
 int fd;				/* fd of network socket */
@@ -258,18 +258,34 @@ int no_check = 0;
     host = argv[optind];
     if (atm) {
 	memset(satm,0,sizeof(satm));
-	if (text2atm(host,(struct sockaddr *) &satm,sizeof(satm),T2A_PVC) < 0) {
-	    fprintf(stderr,"invalid ATM address ([itf.]vpi.vci expected)\n");
-	    exit(1);
-	}
-	if (!trans) satm.sap_rxtp.class = ATM_UBR;
-	else if (!pcr) satm.sap_txtp.class = ATM_UBR;
-	    else {
-		    satm.sap_txtp.class = ATM_CBR;
-		    satm.sap_txtp.min_pcr = pcr;
+	if (!host) satm.sas_family = AF_ATMSVC;
+	else if (text2atm(host,(struct sockaddr *) &satm,sizeof(satm),
+	      T2A_PVC | T2A_SVC | T2A_NAME) < 0) {
+		fprintf(stderr,"invalid ATM address (PVC or SVC expected)\n");
+		exit(1);
 	    }
-	satm.sap_rxtp.max_sdu = buflen;
-	satm.sap_txtp.max_sdu = buflen;
+
+#define INIT(type,fld) \
+	if (!trans) ((type *) &satm)->fld##_rxtp.class = ATM_UBR; \
+	else if (!pcr) ((type *) &satm)->fld##_txtp.class = ATM_UBR; \
+	    else { \
+		    ((type *) &satm)->fld##_txtp.class = ATM_CBR; \
+		    ((type *) &satm)->fld##_txtp.min_pcr = pcr; \
+	    } \
+	((type *) &satm)->fld##_rxtp.max_sdu = \
+	  ((type *) &satm)->fld##_txtp.max_sdu = buflen
+
+	switch (satm.sas_family) {
+	    case AF_ATMPVC:
+		INIT(struct sockaddr_atmpvc,sap);
+		break;
+	    case AF_ATMSVC:
+		INIT(struct sockaddr_atmsvc,sas);
+		break;
+	    default:
+		fprintf(stderr,"bad AF %d\n",satm.sas_family);
+		exit(1);
+	}
     }
     else
     if (trans)  {
@@ -335,8 +351,8 @@ int no_check = 0;
 	fprintf(stdout, "  %s\n", atm?"atm":udp?"udp":"tcp");
     }
 
-    if ((fd = socket(atm ? PF_ATMPVC : AF_INET, udp?SOCK_DGRAM:SOCK_STREAM,
-	atm ? ATM_AAL5 : 0)) < 0) err("socket");
+    if ((fd = socket(atm ? satm.sas_family : AF_INET,
+        udp?SOCK_DGRAM:SOCK_STREAM, atm ? ATM_AAL5 : 0)) < 0) err("socket");
     
     mes("socket");
 	if (!atm)
@@ -361,10 +377,13 @@ int no_check = 0;
     }
 #endif
 
-    if (bind(fd, atm ? &satm : &sinme, atm ? sizeof(satm) : sizeof(sinme)) < 0)
-	err("bind");
+    if (!atm || satm.sas_family == AF_ATMPVC || !trans)
+	if (bind(fd, atm ? &satm : &sinme, atm ? satm.sas_family == AF_ATMPVC ?
+	  sizeof(struct sockaddr_atmpvc) : sizeof(struct sockaddr_atmsvc) :
+	  sizeof(sinme)) < 0)
+	    err("bind");
     
-    if (!udp) {
+    if (!udp || (atm && satm.sas_family == AF_ATMSVC)) {
 	signal(SIGPIPE, sigpipe);
 	if (trans) {
 	    /* We are the client if transmitting */
@@ -377,7 +396,8 @@ int no_check = 0;
 			err("setsockopt");
 	    }
 	    
-	    if (connect(fd, &sinhim, sizeof(sinhim) ) < 0)
+	    if (connect(fd, atm ? &satm : &sinhim, atm ? sizeof(satm) :
+	      sizeof(sinhim)) < 0)
 		err("connect");
 	    
 	    mes("connect");
